get_restricted_boot_parameters

Function get_restricted_boot_parameters 

pub fn get_restricted_boot_parameters(
    group_available_vec: &[Group],
    boot_parameter_vec: &[BootParameters],
) -> Vec<BootParameters>
Get a vector of boot parameters that are restricted based on the groups available to the user.